/**********************************************************************
 * Copyright (C) 2022 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 ***********************************************************************/

import type { ConfigurationRegistry, IConfigurationNode } from './configuration-registry';
import type { ProviderRegistry } from './provider-registry';

export class AutostartEngine {
  constructor(private configurationRegistry: ConfigurationRegistry, private providerRegistry: ProviderRegistry) {}

  async init(): Promise<void> {
    // add configuration
    const autoStartConfigurationNode: IConfigurationNode = {
      id: 'preferences.engine.autostart',
      title: 'Autostart container engine',
      type: 'object',
      properties: {
        ['preferences.engine.autostart']: {
          description: 'Autostart container engine when launching Podman Desktop',
          type: 'boolean',
          default: true,
        },
      },
    };

    this.configurationRegistry.registerConfigurations([autoStartConfigurationNode]);
  }

  async start(): Promise<void> {
    // grab value
    const autoStartConfiguration = this.configurationRegistry.getConfiguration('preferences.engine');
    const autostart = autoStartConfiguration.get<boolean>('autostart');
    if (autostart) {
      console.log('Autostarting container engine');
      // send autostart
      this.providerRegistry.runAutostart();
    }

    // start the engine if we toggle the property
    this.configurationRegistry.onDidChangeConfiguration(e => {
      if (e.key === 'preferences.engine.autostart') {
        if (e.value === true) {
          this.providerRegistry.runAutostart();
        }
      }
    });
  }
}
